@@ -47,7 +47,7 @@ test_that("Zbeta_Zscore calculates Zbeta_Zscore statistic correctly", {
                                 -0.298557987824230,
                                 -0.278980061934724,
                                  NA,NA,NA,NA)
-               ))
+               ),tolerance=0.0001)
 })
 
 ## Test the function with a different window size
@@ -64,7 +64,7 @@ test_that("Zbeta_Zscore calculates Zbeta_Zscore statistic correctly with a diffe
                                 -0.308094601136825,
                                 -0.264295466759451,
                                  NA,NA,NA,NA,NA)
-               ))
+               ),tolerance=0.0001)
 })
 ## Test the function with a character matrix as x
 
@@ -85,7 +85,7 @@ test_that("Zbeta_Zscore calculates Zbeta_Zscore statistic correctly with charact
                                 -0.298557987824230,
                                 -0.278980061934724,
                                  NA,NA,NA,NA)
-               ))
+               ),tolerance=0.0001)
 })
 
 ## Test the function with X supplied as a parameter
@@ -332,4 +332,22 @@ test_that("Zbeta_Zscore fails when LDprofile_bins and LDprofile_sd are different
                "LDprofile_sd must contain the same number of values as there are bins given in LDprofile_bins")
 })
 
+## test that Zbeta_Zscore works with a missing value
+df1<-df
+df1$C1[15]<-NA
+test_that("Zbeta_Zscore calculates Zbeta_Zscore statistic correctly with missing value", {
 
+  expect_equal(Zbeta_Zscore(pos = df1$POS, ws  = 3000, x = as.matrix(df1[,3:7]), dist = df1$dist, LDprofile_bins = LDprofile$bin, LDprofile_rsq = LDprofile$rsq, LDprofile_sd = LDprofile$sd, minRandL = 4, minRL = 25, X = NULL),
+               list(
+                 position=c(100,200,300,400,500,600,700,800,900,1000,1100,1200,1300,1400,1500),
+                 Zbeta_Zscore=c(NA,NA,NA,NA,
+                                -0.273427430734028,
+                                -0.322886149060994,
+                                -0.332297266849268,
+                                -0.272829789964421,
+                                -0.301705254123099,
+                                -0.280921980725937,
+                                -0.253883231792888,
+                                NA,NA,NA,NA)
+               ),tolerance=0.0001)
+})
